@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: dbmanager.php,v 1.2 2003/10/26 08:28:42 wellwine Exp $
+ * $Id: dbmanager.php,v 1.3 2005/03/13 07:07:57 tohokuaiki Exp $
  * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.net/)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -76,6 +76,9 @@ function addColumn($post) {
         } else if ($column=='dohtml') {
             $sql = sprintf('ALTER TABLE %s ADD dohtml TINYINT( 1 ) DEFAULT \'0\' NOT NULL',
                            $xoopsDB->prefix('weblog'));
+        } else if ($column=='trackbacks') {
+            $sql = sprintf('ALTER TABLE %s ADD trackbacks INT(11) NOT NULL default \'0\' ',
+                           $xoopsDB->prefix('weblog'));
 
         } else {
             redirect_header('dbmanager.php', 2, _AM_WEBLOG_UNSUPPORTED);
@@ -118,6 +121,18 @@ function addTable($post) {
         $sql .= 'priv_gid smallint(5) unsigned NOT NULL default \'0\',';
         $sql .= 'PRIMARY KEY  (priv_id)';
         $sql .= ') TYPE=MyISAM;';
+    } else if ($table=='weblog_trackback') {
+        $sql = sprintf('CREATE TABLE %s(', $xoopsDB->prefix('weblog_trackback'));
+        $sql .= 'blog_id mediumint(9) NOT NULL ,';
+        $sql .= 'tb_url text NOT NULL,';
+        $sql .= 'blog_name varchar(255) NOT NULL,';
+        $sql .= 'title varchar(255) NOT NULL,';
+        $sql .= 'description text NOT NULL,';
+        $sql .= 'link text NOT NULL,';
+        $sql .= 'direction enum(\'\',\'transmit\',\'recieved\') NOT NULL default \'\',';
+        $sql .= 'trackback_created int(10) NOT NULL default \'0\',';
+        $sql .= 'PRIMARY KEY  (blog_id,tb_url(100),direction)';
+        $sql .= ') TYPE=MyISAM;';
     } else {
         redirect_header('dbmanager.php', 2, _AM_WEBLOG_UNSUPPORTED);
         exit();
@@ -151,7 +166,7 @@ function checkTables() {
 
     // checking table 'weblog'
     $columns = array('blog_id', 'user_id', 'cat_id', 'created', 'title',
-                     'contents', 'private', 'comments', 'reads', 'dohtml');
+                     'contents', 'private', 'comments', 'reads', 'trackbacks', 'dohtml');
     checkTable('weblog', $columns);
 
     echo "<br />";
@@ -164,6 +179,11 @@ function checkTables() {
     $columns = array('priv_id', 'priv_gid');
     checkTable('weblog_priv', $columns);
 
+    echo "<br />";
+    // checking table 'weblog_trackback'
+    $columns = array('blog_id', 'tb_url', 'blog_name', 'title', 'description', 'link', 'direction', 'trackback_created');
+    checkTable('weblog_trackback', $columns);
+
     xoops_cp_footer();
 }
 
@@ -231,6 +251,7 @@ function synchronizeComments() {
     exit();
 }
 
+
 switch ($action) {
     case "comments":
         synchronizeComments();
