@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: menu.php,v 1.2 2003/10/26 08:28:42 wellwine Exp $
+ * $Id: menu.php,v 1.3 2005/03/11 18:00:21 tohokuaiki Exp $
  * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,4 +28,6 @@ $adminmenu[2]['title'] = _MI_WEBLOG_PRIVMANAGER;
 $adminmenu[2]['link'] = "admin/privmanager.php";
 $adminmenu[3]['title'] = _MI_WEBLOG_DBMANAGER;
 $adminmenu[3]['link'] = "admin/dbmanager.php";
+$adminmenu[4]['title'] = _MI_WEBLOG_MYBLOCKSADMIN ;
+$adminmenu[4]['link'] = "admin/myblocksadmin.php" ;
 ?>
\ No newline at end of file
