@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: details.php,v 1.5 2003/10/26 08:28:42 wellwine Exp $
+ * $Id: details.php,v 1.10 2005/03/20 11:20:20 tohokuaiki Exp $
  * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.net/)
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 include('header.php');
 include_once(sprintf('%s/modules/%s/class/class.weblog.php', XOOPS_ROOT_PATH, $xoopsModule->dirname()));
 include_once(sprintf('%s/modules/%s/class/class.weblogcategories.php', XOOPS_ROOT_PATH, $xoopsModule->dirname()));
+include_once(sprintf('%s/modules/%s/class/class.weblogtrackback.php', XOOPS_ROOT_PATH, $xoopsModule->dirname()));
 
 // obtain GET/POST parameters
 $blog_id = !empty($_GET['blog_id']) ? intval($_GET['blog_id']) : 0;
@@ -54,6 +55,29 @@ if (!$entryObject) {
                   _BL_PRIVATE_NOTEXIST_SORRY);
   exit();
 }
+// obtain trackback
+$tb_operator =& Weblog_Trackback_Operator::getInstance() ;
+$trackback_array = $tb_operator->handler->get( $entryObject->getVar('blog_id') ) ;
+  $trackback_transmit = array() ;
+  $trackback_recieved = array() ;
+if( $trackback_array ){
+	foreach( $trackback_array as $trackback_obj ){
+		$trackback_data = array(
+		                                  "tb_url"=> $trackback_obj->getVar('tb_url'),
+										  "blog_name"=> $trackback_obj->getVar('blog_name'),
+										  "title"=> $trackback_obj->getVar('title'),
+										  "description"=> xoops_substr( $trackback_obj->getVar('description') , 0 , 120 ),
+										  "link"=> $trackback_obj->getVar('link'),
+										  "trackback_created"=> date("Y-m-d/H:i:s" , $trackback_obj->getVar('trackback_created'))
+										  ) ;
+		if( $trackback_obj->getVar('direction') == "transmit" ){
+			$trackback_transmit[] = $trackback_data ;
+		}elseif( $trackback_obj->getVar('direction') == "recieved" ){
+			$trackback_recieved[] = $trackback_data ;
+		}
+	}
+}
+$weblog_trackback_url = XOOPS_URL.'/modules/'.$xoopsModule->dirname().'/weblog-tb.php/'.$blog_id  ;
 
 // wellwine for cookie begins
 // Read in cookie
@@ -87,6 +111,25 @@ if ($xoopsModuleConfig['showavatar']) {
     }
 }
 
+// create rdf 
+include_once(sprintf('%s/modules/%s/include/PEAR/Net/TrackBack.php', XOOPS_ROOT_PATH , $xoopsModule->dirname()));
+$net_trackback =& new Net_TrackBack() ;
+if( $xoopsConfig['default_TZ'] < 0 ){
+  $TZ = "-" . sprintf('%02d' , abs($xoopsConfig['default_TZ']) ) . ':00';
+}else{
+  $TZ = "+" . sprintf('%02d' , $xoopsConfig['default_TZ'] ) . ':00';
+}
+$rdf_source_data = array(
+  'about'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $xoopsModule->dirname() , $entryObject->getVar('blog_id') ) ,
+  'ping'=> $weblog_trackback_url ,
+  'title'=> addslashes($entryObject->getVar('title')) ,
+  'identifier'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $xoopsModule->dirname() , $entryObject->getVar('blog_id') ) ,
+  'description'=> addslashes(xoops_substr( $entryObject->getVar('contents' , 'n') , 0 , 120 )) ,
+  'creator'=> $entryObject->getVar('uname'),
+  'date'=> date("Y-m-d\TH:i:s" , $entryObject->getVar('created')) . $TZ
+) ;
+$rdf_desc = "<!-- \n" . $net_trackback->toEmbededRDF($rdf_source_data) . "-->\n";
+
 // Include the page header
 include(XOOPS_ROOT_PATH.'/header.php');
 
@@ -117,8 +160,12 @@ $xoopsTpl->assign('profileUri', sprintf('%s/userinfo.php?uid=%d', XOOPS_URL, $en
 $xoopsTpl->assign('current_uid', $currentuid);
 $xoopsTpl->assign('is_private', $entryObject->getVar('private') == 'Y' ? 1 : 0);
 $xoopsTpl->assign('private', _BL_PRIVATE);
+$xoopsTpl->assign('lang_comments', _BL_COMMENTS);
+$xoopsTpl->assign('comments_num', $entryObject->getVar('comments'));
 $xoopsTpl->assign('lang_reads', _BL_NUMBER_OF_READS);
 $xoopsTpl->assign('reads', $entryObject->getVar('reads'));
+$xoopsTpl->assign('lang_trackbacks', _BL_NUMBER_OF_TRACKBACKS);
+$xoopsTpl->assign('trackbacks', $entryObject->getVar('trackbacks'));
 $xoopsTpl->assign('edit_text', _BL_EDIT);
 $xoopsTpl->assign('read_users_blog',sprintf('<a href="index.php?user_id=%d">%s</a>',
                                             $entryObject->getVar('user_id'),
@@ -132,15 +179,40 @@ $xoopsTpl->assign('lang_printerpage', _BL_PRINTERPAGE);
 $xoopsTpl->assign('mail_link', 'mailto:?subject='.sprintf(_BL_INTARTICLE,$xoopsConfig['sitename']).'&amp;body='.sprintf(_BL_INTARTFOUND, $xoopsConfig['sitename']).':  '.XOOPS_URL.'/modules/'.$xoopsModule->dirname().'/details.php?blog_id='.$blog_id);
 $xoopsTpl->assign('lang_sendstory', _BL_SENDSTORY);
 
-$rss = sprintf('%s/modules/%s/backend_weblog.php', XOOPS_URL, $xoopsModule->dirname());
-$rss .= sprintf('?user_id=%d', $entryObject->getVar('user_id'));
+$rss_feeder = sprintf('%s/modules/%s/backend_weblog.php', XOOPS_URL, $xoopsModule->dirname());
+$rss_feeder .= sprintf('?user_id=%d', $entryObject->getVar('user_id'));
+$rdf_feeder = sprintf('%s/modules/%s/weblog-rdf.php', XOOPS_URL, $xoopsModule->dirname());
+$rdf_feeder .= sprintf('?user_id=%d', $entryObject->getVar('user_id'));
 $xoopsTpl->assign('lang_rss', sprintf(_BL_RSS_RECENT_FOR, $entryObject->getVar('uname')));
-$xoopsTpl->assign('rss_feeder', $rss);
+$xoopsTpl->assign('rss_feeder', $rss_feeder);
+$xoopsTpl->assign('rdf_feeder', $rdf_feeder);
 $xoopsTpl->assign('rss_show', $xoopsModuleConfig['rssshow']);
+$xoopsTpl->assign('rdf_desc', $rdf_desc);
 
 $xoopsTpl->assign('page_title', $xoopsModule->name());
 $xoopsTpl->assign('page_subtitle', sprintf(_BL_ENTRY_FOR, $entryObject->getVar('uname')));
 
+$prevnext_id = $weblog->getPrevNext($blog_id , $currentuid , $isAdmin) ;
+if($prevnext_id['next']){
+    $xoopsTpl->assign('next_blogentry' , sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL, $xoopsModule->dirname(), $prevnext_id['next'] ));
+    $xoopsTpl->assign('next', _BL_NEXT);
+}
+if($prevnext_id['prev']){
+    $xoopsTpl->assign('prev_blogentry' , sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL, $xoopsModule->dirname(), $prevnext_id['prev'] ));
+    $xoopsTpl->assign('prev', _BL_PREV);
+}
+$xoopsTpl->assign('trackback_transmit' , $trackback_transmit ) ;
+$xoopsTpl->assign('trackback_recieved' , $trackback_recieved ) ;
+$xoopsTpl->assign('lang_trackback_anounce' , _BL_TRACKBACK_ANOUNCE ) ;
+$xoopsTpl->assign('weblog_trackback_url' , $weblog_trackback_url) ;
+$xoopsTpl->assign('lang_trackback_transmit' , _BL_TRACKBACK_TRANSMIT ) ;
+$xoopsTpl->assign('lang_trackback_recieved' , _BL_TRACKBACK_RECIEVED ) ;
+
+$weblog_head = sprintf('<link rel="stylesheet" type="text/css" media="all" href="%s/modules/%s/styles.css" />'."\n" , XOOPS_URL , $xoopsModule->dirname() );
+$weblog_head .= sprintf('<link rel="alternate" type="application/rss+xml" title="RSS" href="%s" />'."\n" , $rss_feeder );
+$weblog_head .= sprintf('<link rel="alternate" type="application/rdf+xml" title="RDF" href="%s" />'."\n" , $rdf_feeder );
+$xoopsTpl->assign('xoops_module_header', $weblog_head , $entryObject->getVar('user_id') );
+
 // Include the commenting module
 require XOOPS_ROOT_PATH.'/include/comment_view.php';
 
