@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: index.php,v 1.6 2003/10/30 12:34:52 wellwine Exp $
+ * $Id: index.php,v 1.10 2005/03/14 17:37:31 tohokuaiki Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
  *
@@ -128,6 +128,12 @@ if ( $count > $perPage ) {
   if ($user_id>0) {
     $uri .= 'user_id='.$user_id;
   }
+  if ($cat_id>0) {
+    if (strlen($uri)>0) {
+      $uri .= '&';
+    }
+    $uri .= 'cat_id='.$cat_id;
+  }
   include XOOPS_ROOT_PATH.'/class/pagenav.php';
   $nav = new XoopsPageNav($count, $perPage, $start, "start", $uri);
   $xoopsTpl->assign('pagination', $nav->renderNav());
@@ -154,6 +160,25 @@ foreach ($result as $entryObject) {
     setcookie(WEBLOG_COOKIE_READ, serialize($weblog_read), $curtime+$xoopsModuleConfig['expiration'], $weblogCookie['path'], $weblogCookie['domain'], $weblogCookie['secure']);
     // wellwine for cookie ends
   }
+  // create rdf 
+  include_once(sprintf('%s/modules/%s/include/PEAR/Net/TrackBack.php', XOOPS_ROOT_PATH , $xoopsModule->dirname()));
+  $weblog_trackback_url = XOOPS_URL.'/modules/'.$xoopsModule->dirname().'/weblog-tb.php/'. $entryObject->getVar('blog_id')  ;
+  $net_trackback =& new Net_TrackBack() ;
+  if( $xoopsConfig['default_TZ'] < 0 ){
+    $TZ = "-" . sprintf('%02d' , abs($xoopsConfig['default_TZ']) ) . ':00';
+  }else{
+    $TZ = "+" . sprintf('%02d' , $xoopsConfig['default_TZ'] ) . ':00';
+  }
+  $rdf_source_data = array(
+    'about'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $xoopsModule->dirname() , $entryObject->getVar('blog_id') ) ,
+    'ping'=> $weblog_trackback_url ,
+    'title'=> addslashes($entryObject->getVar('title')) ,
+    'identifier'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $xoopsModule->dirname() , $entryObject->getVar('blog_id') ),
+    'description'=> addslashes(xoops_substr( $entryObject->getVar('contents' , 'n') , 0 , 120 ) ),
+    'creator'=> $entryObject->getVar('uname'),
+    'date'=> date("Y-m-d\TH:i:s" , $entryObject->getVar('created')) . $TZ
+  ) ;
+  $rdf_desc = "<!-- \n" . $net_trackback->toEmbededRDF($rdf_source_data) . "-->\n";
 
   // Retrieve his/her avatar
   $entry['use_avatar'] = 0;
@@ -187,7 +212,7 @@ foreach ($result as $entryObject) {
   $entry['profileUri'] = sprintf('%s/userinfo.php?uid=%d', XOOPS_URL, $entryObject->getVar('user_id'));
   $entry['blog_id'] = $entryObject->getVar('blog_id');
   $entry['comments'] = $entryObject->getVar('comments');
-  $entry['comlink'] = sprintf('%s/modules/%s/details.php?blog_id=%d',
+  $entry['comlink'] = sprintf('%s/modules/%s/details.php?blog_id=%d#comment',
                               XOOPS_URL, $xoopsModule->dirname(), $entryObject->getVar('blog_id'));
   $entry['lang_comments'] = _BL_COMMENTS;
 
@@ -199,16 +224,24 @@ foreach ($result as $entryObject) {
   $entry['provide_edit_link'] = ($isAdmin || ($currentuid==$entryObject->getVar('user_id') && $priv->hasPrivilege($currentUser)))?1:0;
   $entry['lang_reads'] = _BL_NUMBER_OF_READS;
   $entry['reads'] = $entryObject->getVar('reads');
+  $entry['trackbacks'] = $entryObject->getVar('trackbacks');
+  $entry['tracklink'] = sprintf('%s/modules/%s/details.php?blog_id=%d#trackback',
+                              XOOPS_URL, $xoopsModule->dirname(), $entryObject->getVar('blog_id'));
+  $entry['lang_trackbacks'] = _BL_NUMBER_OF_TRACKBACKS;
+  $entry['rdf_desc'] = $rdf_desc ;
   $xoopsTpl->append('entries', $entry);
 }
 
 // wellwine
 $rss = sprintf('%s/modules/%s/backend_weblog.php', XOOPS_URL, $xoopsModule->dirname());
+$rdf = sprintf('%s/modules/%s/weblog-rdf.php', XOOPS_URL, $xoopsModule->dirname());
 if ($user_id>0) {
     $rss .= sprintf('?user_id=%d', $user_id);
+    $rdf .= sprintf('?user_id=%d', $user_id);
 }
 $xoopsTpl->assign('lang_rss', $page_rss);
 $xoopsTpl->assign('rss_feeder', $rss);
+$xoopsTpl->assign('rdf_feeder', $rdf);
 $xoopsTpl->assign('rss_show', $xoopsModuleConfig['rssshow']);
 
 $xoopsTpl->assign('page_title', $xoopsModule->name());
@@ -227,6 +260,10 @@ $cat_url .= $weblogcat->getNicePathFromId($cat_id, sprintf('%s/modules/%s/index.
 $xoopsTpl->assign('cat_url', $cat_url);
 //$xoopsTpl->assign('lang_blog', _BL_BLOG);
 //$xoopsTpl->assign('lang_delete', _BL_DELETE);
+$weblog_head = sprintf('<link rel="stylesheet" type="text/css" media="all" href="%s/modules/%s/styles.css" />'."\n" , XOOPS_URL , $xoopsModule->dirname() );
+$weblog_head .= sprintf('<link rel="alternate" type="application/rss+xml" title="RSS" href="%s" />'."\n" , $rss );
+$weblog_head .= sprintf('<link rel="alternate" type="application/rdf+xml" title="RDF" href="%s" />'."\n" , $rdf );
+$xoopsTpl->assign('xoops_module_header', $weblog_head , $user_id );
 
 // Include the page footer
 include(XOOPS_ROOT_PATH.'/footer.php');
