@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: blocks.php,v 1.3 2003/08/29 14:10:29 wellwine Exp $
+ * $Id: blocks.php,v 1.4 2005/03/16 16:04:36 tohokuaiki Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,9 +24,16 @@
  */
 
 define('_MB_RECENT_EDIT_NUMBER_OF_ENTRIES','Nombre d\'articles &agrave; afficher');
+define('_MB_WEBLOG_EDIT_LINK_TO_LIST', 'Link authors to their entries? (0=No,1=Yes)'); //eng
 define('_MB_RECENT_EDIT_MAX_TITLE_LENGTH','Longueur maximale du titre');
 define('_MB_RECENT_EDIT_DATE_FORMAT','Format date');
 define('_MB_RECENT_EDIT_USE_AVATARS','Utiliser les avatars? (0=No,1=Yes)');
-define('_MB_RECENT_EDIT_TYPE','Type (1=Titre raccouri, 2=Titre+Nom user, 3=Titre+Nom+Avatar)');
+define('_MB_RECENT_EDIT_TYPE','Type (1=Titre raccour, 2=Titre+Nom user, 3=Titre+Nom+Avatar)');
 
+define('_MB_WEBLOG_LANG_TITLE', 'Title'); // eng
+define('_MB_WEBLOG_LANG_AUTHOR', 'Author'); // eng
+define('_MB_WEBLOG_LANG_COMMENTS', 'Comments'); // eng
+define('_MB_WEBLOG_LANG_POSTED', 'Posted'); // eng
+define('_MB_WEBLOG_LANG_READS', 'Reads'); // eng
+define('_MB_WEBLOG_LANG_MOREWEBLOGS', 'More weBLogs'); // eng
 ?>
