@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: modinfo.php,v 1.4 2003/10/26 08:28:42 wellwine Exp $
+ * $Id: modinfo.php,v 1.5 2005/03/13 07:07:57 tohokuaiki Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.net/)
  *
@@ -41,6 +41,7 @@ define('_MI_WEBLOG_SMNAME3','');
 define('_MI_WEBLOG_DBMANAGER', 'ǡ١');
 define('_MI_WEBLOG_CATMANAGER', 'ƥ');
 define('_MI_WEBLOG_PRIVMANAGER', '´');
+define('_MI_WEBLOG_MYBLOCKSADMIN', '֥å');
 
 define('_MI_WEBLOG_NOTIFY','ɽΥ֥');
 define('_MI_WEBLOG_NOTIFYDSC','Υ֥ѹäΤ');
@@ -77,6 +78,12 @@ define('_MI_WEBLOG_MINENTRYSIZE','ȥκ㥵');
 define('_MI_WEBLOG_MINENTRYSIZEDSC','0ꤹȥåޤ');
 define('_MI_WEBLOG_IMGURL', 'URL');
 define('_MI_WEBLOG_IMGURLDSC', 'ѥڡRSSɽޤϵҤURLꤷޤ');
+define('_MI_WEBLOG_OPDOHTML', 'ץ/HTML̵') ;
+define('_MI_WEBLOG_OPDOHTMLDSC', 'HTML̵פΥץǥեȤǥåξ֤ˤ"Ϥ"') ;
+define('_MI_WEBLOG_OPPRIVATE', 'ץ/ץ饤١') ;
+define('_MI_WEBLOG_OPPRIVATEDSC', '֥ץ饤١ȡפΥץǥեȤǥåξ֤ˤ"Ϥ"') ;
+define('_MI_WEBLOG_OPUPDATEPING', 'ץ/Ping') ;
+define('_MI_WEBLOG_OPUPDATEPINGDSC', 'ֹPingפΥץǥեȤǥåξ֤ˤ"Ϥ"') ;
 
 define('_MI_WEBLOG_UPDATE_READS_WHEN','򥫥ȥåפΤ');
 define('_MI_WEBLOG_UPDATE_READS_WHENDSC','־ܺ٤줿ȤפǤϾܺٲ̤ǥȥȤ֥桼ΥꥹȤ줿ȤפǤϤ桼ΥȥꥹȥåפȤ֥ꥹȤ줿ȤפǤϤɤʷǤ쥨ȥ꤬ꥹȥåפ줿Ȥ줾ޤ');
