@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: blocks.php,v 1.2 2003/08/29 13:43:58 wellwine Exp $
+ * $Id: blocks.php,v 1.4 2005/03/16 16:12:13 tohokuaiki Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,9 +23,18 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
-define('_MB_RECENT_EDIT_NUMBER_OF_ENTRIES','Nmero de ingresos a mostrar');
-define('_MB_RECENT_EDIT_MAX_TITLE_LENGTH','Mxima longitud del ttulo');
+define('_MB_RECENT_EDIT_NUMBER_OF_ENTRIES','Nero de ingresos a mostrar');
+define('_MB_WEBLOG_EDIT_LINK_TO_LIST', 'Link authors to their entries? (0=No,1=Yes)'); //eng
+define('_MB_RECENT_EDIT_MAX_TITLE_LENGTH','Mima longitud del tulo');
 define('_MB_RECENT_EDIT_DATE_FORMAT','Formato de la fecha');
 define('_MB_RECENT_EDIT_USE_AVATARS','Usar avatars? (0=No,1=Si)');
-define('_MB_RECENT_EDIT_TYPE','Tipo (1=pequeo,2=mediano,3=largo)');
+define('_MB_RECENT_EDIT_TYPE','Tipo (1=peque,2=mediano,3=largo)');
+
+define('_MB_WEBLOG_LANG_TITLE', 'Title'); // eng
+define('_MB_WEBLOG_LANG_AUTHOR', 'Author'); // eng
+define('_MB_WEBLOG_LANG_COMMENTS', 'Comments'); // eng
+define('_MB_WEBLOG_LANG_POSTED', 'Posted'); // eng
+define('_MB_WEBLOG_LANG_READS', 'Reads'); // eng
+define('_MB_WEBLOG_LANG_MOREWEBLOGS', 'More weBLogs'); // eng
+
 ?>
\ No newline at end of file
